@@ -1458,7 +1458,11 @@ class EntryResource(CustomOperationResourceMixin,
     def redacted_fields(self):
         """Names the fields the current user doesn't have permission to see."""
         failures = []
-        checker = getChecker(self.context)
+        try:
+            checker = getChecker(self.context)
+        except TypeError:
+            # There's no permission checker.
+            checker = None
         for name, field in getFieldsInOrder(self.entry.schema):
             try:
                 # Can we view the field's value? We check the
@@ -1466,9 +1470,30 @@ class EntryResource(CustomOperationResourceMixin,
                 # checker, because doing it indirectly by fetching the
                 # value may have very slow side effects such as
                 # database hits.
-                tagged_values = field.getTaggedValue('lazr.restful.exported')
-                original_name = tagged_values['original_name']
-                checker.check(self.context, original_name)
+                try:
+                    tagged_values = field.getTaggedValue(
+                        'lazr.restful.exported')
+                    original_name = tagged_values['original_name']
+                except KeyError, e:
+                    # This field has no tagged values, or is missing
+                    # the 'original_name' value. Its entry class was
+                    # probably created by hand rather than by tagging
+                    # an interface. In that case, it's the
+                    # programmer's responsibility to set
+                    # 'original_name' if the web service field name
+                    # differs from the underlying interface's field
+                    # name. Since 'original_name' is not present, assume the
+                    # names are the same.
+                    original_name = name
+                if checker is None:
+                    # This is more expensive than using a Zope
+                    # checker, but there is no checker, so either
+                    # there is no permission control on this object,
+                    # or permission control is implemented some other
+                    # way.
+                    getattr(self.context, original_name)
+                else:
+                    checker.check(self.context, original_name)
             except Unauthorized:
                 # This is an expensive operation that will make this
                 # request more expensive still, but it happens
@@ -1502,22 +1527,21 @@ class EntryResource(CustomOperationResourceMixin,
         if media_type in [self.WADL_TYPE, self.DEPRECATED_WADL_TYPE]:
             return self.toWADL().encode("utf-8")
         elif media_type == self.JSON_TYPE:
-            cache = None
-            try:
-                cache = getUtility(IRepresentationCache)
+            cache = self._representation_cache
+            if cache is None:
+                representation = None
+            else:
                 representation = cache.get(
                     self.context, self.JSON_TYPE, self.request.version)
-            except ComponentLookupError:
-                # There's no representation cache.
-                representation = None
 
             redacted_fields = self.redacted_fields
             if representation is None:
-                # Either there is no cache, or the representation
+                # Either there is no active cache, or the representation
                 # wasn't in the cache.
                 representation = simplejson.dumps(self, cls=ResourceJSONEncoder)
-                # If there's a cache, and this representation doesn't
-                # contain any redactions, store it in the cache.
+                # If there's an active cache, and this representation
+                # doesn't contain any redactions, store it in the
+                # cache.
                 if cache is not None and len(redacted_fields) == 0:
                     cache.set(self.context, self.JSON_TYPE,
                               self.request.version, representation)
@@ -1544,6 +1568,19 @@ class EntryResource(CustomOperationResourceMixin,
                     "No representation implementation for media type %s"
                     % media_type)
 
+    @property
+    def _representation_cache(self):
+        """Return the representation cache, or None if missing/disabled."""
+        try:
+            cache = getUtility(IRepresentationCache)
+        except ComponentLookupError:
+            # There's no representation cache.
+            return None
+        config = getUtility(IWebServiceConfiguration)
+        if config.enable_server_side_representation_cache:
+            return cache
+        return None
+
 
 class CollectionResource(BatchingResourceMixin,
                          CustomOperationResourceMixin,
